var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
import { LitElement, html } from 'lit';
import { customElement, property, state } from 'lit/decorators.js';
import { tailwind } from '../../style';
let ResultStatusBar = class ResultStatusBar extends LitElement {
    static styles = [tailwind];
    #observer;
    constructor() {
        super();
        this.detected = 0;
        this.undetected = 0;
        this.invalid = 0;
        this.ignored = 0;
        this.pending = 0;
        this.total = 0;
        this.shouldBeSmall = false;
    }
    connectedCallback() {
        super.connectedCallback();
        // This code is responsible for making the small progress-bar show up.
        // Once this element (the standard progress-bar) is no longer intersecting (visible) the viewable window,
        // the smaller progress-bar will show up at the top if the window.
        // If this element is visible, the smaller progress-bar will fade out and it will no longer be visible.
        this.#observer = new window.IntersectionObserver(([entry]) => {
            if (entry.isIntersecting) {
                this.shouldBeSmall = false;
            }
            else {
                this.shouldBeSmall = true;
            }
            this.requestUpdate();
        });
        this.#observer.observe(this);
    }
    disconnectedCallback() {
        super.disconnectedCallback();
        this.#observer?.disconnect();
    }
    render() {
        return html `
      ${this.#renderSmallParts()}
      <div class="my-4 rounded-md border border-gray-200 bg-white transition-all">
        <div class="relative">
          <div class="parts flex h-8 w-full overflow-hidden rounded bg-gray-200">${this.#renderParts()}</div>
        </div>
      </div>
    `;
    }
    #renderSmallParts() {
        return html `<div
      class="${this.shouldBeSmall ? 'opacity-1' : 'opacity-0'} pointer-events-none fixed left-0 top-0 z-20 flex w-full justify-center transition-all"
    >
      <div class="container w-full bg-white py-2">
        <div class="flex h-2 overflow-hidden rounded bg-gray-200">${this.#getMetrics().map((metric) => this.#renderSmallPart(metric))}</div>
      </div>
    </div>`;
    }
    #renderSmallPart(metric) {
        return html `<div
      class="${this.#colorFromMetric(metric.type)} z-20 h-2 transition-all"
      style="width: ${this.#calculatePercentage(metric.amount)}%"
    ></div>`;
    }
    #renderParts() {
        return html `${this.#getMetrics().map((metric) => this.#renderPart(metric))}`;
    }
    #renderPart(metric) {
        return html `<div
      title="${metric.tooltip}"
      style="width: ${this.#calculatePercentage(metric.amount)}%"
      class="${this.#colorFromMetric(metric.type)} ${metric.amount === 0
            ? 'opacity-0'
            : ''} relative flex h-8 items-center overflow-hidden transition-all"
    >
      <span class="ms-3 font-bold text-gray-800">${metric.amount}</span>
    </div>`;
    }
    #getMetrics() {
        return [
            { type: 'detected', amount: this.detected, tooltip: 'killed + timeout' },
            { type: 'undetected', amount: this.undetected, tooltip: 'survived + no coverage' },
            { type: 'ignored + invalid', amount: this.ignored + this.invalid, tooltip: 'ignored + runtime error + compile error' },
            { type: 'pending', amount: this.pending, tooltip: 'pending' },
        ];
    }
    #colorFromMetric(metric) {
        switch (metric) {
            case 'detected':
                return 'bg-green-600';
            case 'undetected':
                return 'bg-red-600';
            case 'ignored + invalid':
                return 'bg-yellow-600';
            default:
                return 'bg-gray-200';
        }
    }
    #calculatePercentage(metric) {
        return this.total !== 0 ? (100 * metric) / this.total : 0;
    }
};
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "detected", void 0);
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "undetected", void 0);
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "invalid", void 0);
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "ignored", void 0);
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "pending", void 0);
__decorate([
    property({ attribute: false })
], ResultStatusBar.prototype, "total", void 0);
__decorate([
    state()
], ResultStatusBar.prototype, "shouldBeSmall", void 0);
ResultStatusBar = __decorate([
    customElement('mte-result-status-bar')
], ResultStatusBar);
export { ResultStatusBar };
//# sourceMappingURL=result-status-bar.js.map